@@ -1,3 +1,4 @@
+from fsgs.plugins.pluginexecutablefinder import PluginExecutableFinder
 import os
 import subprocess
 
@@ -5,18 +6,15 @@ from fsbc import settings
 from fsgs.option import Option
 from .fsuae import FSUAE
 
-try:
-    getcwd = os.getcwdu
-except AttributeError:
-    getcwd = os.getcwd
-
 
 class FSUAEDeviceHelper(object):
     @classmethod
     def start_with_args(cls, args, **kwargs):
         print("FSUAE.start_with_args:", args)
-        exe = cls.find_executable()
-        print("current dir (cwd): ", getcwd())
+        exe = PluginExecutableFinder().find_executable("fs-uae-device-helper")
+        if exe is None:
+            raise Exception("Could not find fs-uae-device-helper executable")
+        print("current dir (cwd): ", os.getcwd())
         print("using fs-uae executable:", exe)
         args = [exe] + args
         print(args)
@@ -40,7 +38,3 @@ class FSUAEDeviceHelper(object):
             **kwargs
         )
         return process
-
-    @classmethod
-    def find_executable(cls):
-        return FSUAE.find_executable("fs-uae-device-helper")
